# [WIP] Neural Piano
## Hi-Fi neural MIDI piano synthesizer and MIDI renderer

<img width="1024" height="1024" alt="Neural-Piano-Artwork" src="https://github.com/user-attachments/assets/a3d214c0-f88d-4581-9d29-fc26aeec04f8" />

***

## Installation

### pip and setuptools

```sh
# It is recommended that you upgrade pip and setuptools prior to install for max compatibility
!pip install --upgrade pip
!pip install --upgrade setuptools build wheel
```

### pip install

```sh
# The following command will install Neural Piano pip package
# Please note that Neural Piano requires Nvidia GPU with at least 40GB VRAM

!pip install -U neuralpiano
```

***

## Quick-start use example

```python
# Import main Neural Piano module
import neuralpiano

# Render MIDI
neuralpiano.render_midi('input.mid', 'output.wav')
```

***

### Project Los Angeles
### Tegridy Code 2025
